@@ -97,26 +97,37 @@ theme_apa <- function(legend.pos = "topleft", legend.use.title = FALSE,
     panel.grid.minor = ggplot2::element_blank(), # no minor gridlines
     legend.text = ggplot2::element_text(size=legend.font.size),
     legend.key.size = ggplot2::unit(1.5, "lines"),
-    legend.key = ggplot2::element_blank(), # switch off the rectangle around symbols
+    # switch off the rectangle around symbols
+    legend.key = ggplot2::element_blank(),
     strip.text.x = ggplot2::element_text(size=facet.title.size), # facet labels
     strip.text.y = ggplot2::element_text(size=facet.title.size),
-    strip.background = ggplot2::element_rect(colour="white", fill="white") # facet titles
+    # facet titles
+    strip.background = ggplot2::element_rect(colour = "white", fill = "white")
   )
 
-  # Choose legend position. APA figures generally include legends that are embedded
-  # on the plane, so there is no efficient way to have it automatically placed correctly
-  if (legend.pos=="topleft") {
-    plot <- plot + ggplot2::theme(legend.position = c(.05,.95), legend.justification = c(.05,.95)) # manually position the legend (numbers being from 0,0 at bottom left of whole plot to 1,1 at top right)
-  } else if (legend.pos=="topright") {
-    plot <- plot + ggplot2::theme(legend.position = c(.95, .95), legend.justification = c(.95,.95))
-  } else if (legend.pos=="topmiddle") {
-    plot <- plot + ggplot2::theme(legend.position = c(.50, .95), legend.justification = c(.50,.95))
-  } else if (legend.pos=="bottomleft") {
-    plot <- plot + ggplot2::theme(legend.position = c(.05, .05), legend.justification = c(.05,.05))
-  } else if (legend.pos=="bottomright") {
-    plot <- plot + ggplot2::theme(legend.position = c(.95, .05), legend.justification = c(.95,.05))
-  } else if (legend.pos=="bottommiddle") {
-    plot <- plot + ggplot2::theme(legend.position = c(.50, .05), legend.justification = c(.50,.05))
+  # Choose legend position. APA figures generally include legends that
+  # are embedded on the plane, so there is no efficient way to have it
+  # automatically placed correctly
+  if (legend.pos == "topleft") {
+    # manually position the legend (numbers being from 0,0 at bottom left of
+    # whole plot to 1,1 at top right)
+    plot <- plot + ggplot2::theme(legend.position = c(.05,.95),
+                                  legend.justification = c(.05,.95))
+  } else if (legend.pos == "topright") {
+    plot <- plot + ggplot2::theme(legend.position = c(.95, .95),
+                                  legend.justification = c(.95,.95))
+  } else if (legend.pos == "topmiddle") {
+    plot <- plot + ggplot2::theme(legend.position = c(.50, .95),
+                                  legend.justification = c(.50,.95))
+  } else if (legend.pos == "bottomleft") {
+    plot <- plot + ggplot2::theme(legend.position = c(.05, .05),
+                                  legend.justification = c(.05,.05))
+  } else if (legend.pos == "bottomright") {
+    plot <- plot + ggplot2::theme(legend.position = c(.95, .05),
+                                  legend.justification = c(.95,.05))
+  } else if (legend.pos == "bottommiddle") {
+    plot <- plot + ggplot2::theme(legend.position = c(.50, .05),
+                                  legend.justification = c(.50,.05))
   } else if (legend.pos == "none") {
     plot <- plot + ggplot2::theme(legend.position = "none")
   } else {
@@ -124,11 +135,14 @@ theme_apa <- function(legend.pos = "topleft", legend.use.title = FALSE,
   }
 
   # Should legend have title? If so, format it correctly
-  if (legend.use.title==FALSE){
-    plot <- plot + ggplot2::theme(legend.title = ggplot2::element_blank()) # switch off the legend title
+  if (legend.use.title == FALSE) {
+    # switch off the legend title
+    plot <- plot + ggplot2::theme(legend.title = ggplot2::element_blank())
+
   } else {
-    plot <- plot + ggplot2::theme(legend.title = ggplot2::element_text(size=12,
-                                                                      face="bold"))
+    plot <- plot +
+      ggplot2::theme(legend.title =
+                       ggplot2::element_text(size = 12, face = "bold"))
   }
 
   return(plot)
